{% extends "site_base.html" %}

{% block extra_head %}
    {% if STATIC_URL %}
        <link rel="stylesheet" href="{{ STATIC_URL }}tagging_ext/django-tagging-ext.css" />
    {% else %}
        <link rel="stylesheet" href="{{ MEDIA_URL }}tagging_ext/django-tagging-ext.css" />    
    {% endif %}
{% endblock %}